/****************************************************************************
** Meta object code from reading C++ file 'dbusmixerwrapper.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/dbus/dbusmixerwrapper.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusmixerwrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DBusMixerWrapper_t {
    QByteArrayData data[12];
    char stringdata0[113];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DBusMixerWrapper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DBusMixerWrapper_t qt_meta_stringdata_DBusMixerWrapper = {
    {
QT_MOC_LITERAL(0, 0, 16), // "DBusMixerWrapper"
QT_MOC_LITERAL(1, 17, 14), // "controlsChange"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 10), // "changeType"
QT_MOC_LITERAL(4, 44, 10), // "driverName"
QT_MOC_LITERAL(5, 55, 13), // "masterControl"
QT_MOC_LITERAL(6, 69, 12), // "readableName"
QT_MOC_LITERAL(7, 82, 6), // "opened"
QT_MOC_LITERAL(8, 89, 2), // "id"
QT_MOC_LITERAL(9, 92, 3), // "udi"
QT_MOC_LITERAL(10, 96, 7), // "balance"
QT_MOC_LITERAL(11, 104, 8) // "controls"

    },
    "DBusMixerWrapper\0controlsChange\0\0"
    "changeType\0driverName\0masterControl\0"
    "readableName\0opened\0id\0udi\0balance\0"
    "controls"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DBusMixerWrapper[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       8,   22, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,

 // properties: name, type, flags
       4, QMetaType::QString, 0x00095001,
       5, QMetaType::QString, 0x00095001,
       6, QMetaType::QString, 0x00095001,
       7, QMetaType::Bool, 0x00095001,
       8, QMetaType::QString, 0x00095001,
       9, QMetaType::QString, 0x00095001,
      10, QMetaType::Int, 0x00095103,
      11, QMetaType::QStringList, 0x00095001,

       0        // eod
};

void DBusMixerWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DBusMixerWrapper *_t = static_cast<DBusMixerWrapper *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->controlsChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        DBusMixerWrapper *_t = static_cast<DBusMixerWrapper *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->driverName(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->masterControl(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->readableName(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isOpened(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->id(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->udi(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->balance(); break;
        case 7: *reinterpret_cast< QStringList*>(_v) = _t->controls(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        DBusMixerWrapper *_t = static_cast<DBusMixerWrapper *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setBalance(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject DBusMixerWrapper::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_DBusMixerWrapper.data,
      qt_meta_data_DBusMixerWrapper,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DBusMixerWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusMixerWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DBusMixerWrapper.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusMixerWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
