/****************************************************************************
** Meta object code from reading C++ file 'kmixd.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/apps/kmixd.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmixd.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMixD_t {
    QByteArrayData data[13];
    char stringdata0[128];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMixD_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMixD_t qt_meta_stringdata_KMixD = {
    {
QT_MOC_LITERAL(0, 0, 5), // "KMixD"
QT_MOC_LITERAL(1, 6, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 22, 13), // "org.kde.KMixD"
QT_MOC_LITERAL(3, 36, 21), // "delayedInitialization"
QT_MOC_LITERAL(4, 58, 0), // ""
QT_MOC_LITERAL(5, 59, 10), // "saveConfig"
QT_MOC_LITERAL(6, 70, 7), // "plugged"
QT_MOC_LITERAL(7, 78, 11), // "const char*"
QT_MOC_LITERAL(8, 90, 10), // "driverName"
QT_MOC_LITERAL(9, 101, 3), // "udi"
QT_MOC_LITERAL(10, 105, 8), // "QString&"
QT_MOC_LITERAL(11, 114, 3), // "dev"
QT_MOC_LITERAL(12, 118, 9) // "unplugged"

    },
    "KMixD\0D-Bus Interface\0org.kde.KMixD\0"
    "delayedInitialization\0\0saveConfig\0"
    "plugged\0const char*\0driverName\0udi\0"
    "QString&\0dev\0unplugged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMixD[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
       4,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    0,   36,    4, 0x08 /* Private */,
       5,    0,   37,    4, 0x08 /* Private */,
       6,    3,   38,    4, 0x08 /* Private */,
      12,    1,   45,    4, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, QMetaType::QString, 0x80000000 | 10,    8,    9,   11,
    QMetaType::Void, QMetaType::QString,    9,

       0        // eod
};

void KMixD::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMixD *_t = static_cast<KMixD *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->delayedInitialization(); break;
        case 1: _t->saveConfig(); break;
        case 2: _t->plugged((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 3: _t->unplugged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KMixD::staticMetaObject = {
    { &KDEDModule::staticMetaObject, qt_meta_stringdata_KMixD.data,
      qt_meta_data_KMixD,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMixD::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMixD::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMixD.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return KDEDModule::qt_metacast(_clname);
}

int KMixD::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDEDModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
