/****************************************************************************
** Meta object code from reading C++ file 'dialogviewconfiguration.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/gui/dialogviewconfiguration.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dialogviewconfiguration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DialogViewConfigurationWidget_t {
    QByteArrayData data[9];
    char stringdata0[134];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DialogViewConfigurationWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DialogViewConfigurationWidget_t qt_meta_stringdata_DialogViewConfigurationWidget = {
    {
QT_MOC_LITERAL(0, 0, 29), // "DialogViewConfigurationWidget"
QT_MOC_LITERAL(1, 30, 7), // "dropped"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 30), // "DialogViewConfigurationWidget*"
QT_MOC_LITERAL(4, 70, 4), // "list"
QT_MOC_LITERAL(5, 75, 5), // "index"
QT_MOC_LITERAL(6, 81, 28), // "DialogViewConfigurationItem*"
QT_MOC_LITERAL(7, 110, 4), // "item"
QT_MOC_LITERAL(8, 115, 18) // "sourceIsActiveList"

    },
    "DialogViewConfigurationWidget\0dropped\0"
    "\0DialogViewConfigurationWidget*\0list\0"
    "index\0DialogViewConfigurationItem*\0"
    "item\0sourceIsActiveList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DialogViewConfigurationWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    4,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, 0x80000000 | 6, QMetaType::Bool,    4,    5,    7,    8,

       0        // eod
};

void DialogViewConfigurationWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DialogViewConfigurationWidget *_t = static_cast<DialogViewConfigurationWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dropped((*reinterpret_cast< DialogViewConfigurationWidget*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< DialogViewConfigurationItem*(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DialogViewConfigurationWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (DialogViewConfigurationWidget::*_t)(DialogViewConfigurationWidget * , int , DialogViewConfigurationItem * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DialogViewConfigurationWidget::dropped)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject DialogViewConfigurationWidget::staticMetaObject = {
    { &QListWidget::staticMetaObject, qt_meta_stringdata_DialogViewConfigurationWidget.data,
      qt_meta_data_DialogViewConfigurationWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DialogViewConfigurationWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DialogViewConfigurationWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DialogViewConfigurationWidget.stringdata0))
        return static_cast<void*>(this);
    return QListWidget::qt_metacast(_clname);
}

int DialogViewConfigurationWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void DialogViewConfigurationWidget::dropped(DialogViewConfigurationWidget * _t1, int _t2, DialogViewConfigurationItem * _t3, bool _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_DialogViewConfiguration_t {
    QByteArrayData data[14];
    char stringdata0[240];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DialogViewConfiguration_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DialogViewConfiguration_t qt_meta_stringdata_DialogViewConfiguration = {
    {
QT_MOC_LITERAL(0, 0, 23), // "DialogViewConfiguration"
QT_MOC_LITERAL(1, 24, 5), // "apply"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 11), // "slotDropped"
QT_MOC_LITERAL(4, 43, 30), // "DialogViewConfigurationWidget*"
QT_MOC_LITERAL(5, 74, 4), // "list"
QT_MOC_LITERAL(6, 79, 5), // "index"
QT_MOC_LITERAL(7, 85, 28), // "DialogViewConfigurationItem*"
QT_MOC_LITERAL(8, 114, 4), // "item"
QT_MOC_LITERAL(9, 119, 18), // "sourceIsActiveList"
QT_MOC_LITERAL(10, 138, 25), // "moveSelectionToActiveList"
QT_MOC_LITERAL(11, 164, 27), // "moveSelectionToInactiveList"
QT_MOC_LITERAL(12, 192, 22), // "selectionChangedActive"
QT_MOC_LITERAL(13, 215, 24) // "selectionChangedInactive"

    },
    "DialogViewConfiguration\0apply\0\0"
    "slotDropped\0DialogViewConfigurationWidget*\0"
    "list\0index\0DialogViewConfigurationItem*\0"
    "item\0sourceIsActiveList\0"
    "moveSelectionToActiveList\0"
    "moveSelectionToInactiveList\0"
    "selectionChangedActive\0selectionChangedInactive"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DialogViewConfiguration[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x0a /* Public */,
       3,    4,   45,    2, 0x08 /* Private */,
      10,    0,   54,    2, 0x08 /* Private */,
      11,    0,   55,    2, 0x08 /* Private */,
      12,    0,   56,    2, 0x08 /* Private */,
      13,    0,   57,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, 0x80000000 | 7, QMetaType::Bool,    5,    6,    8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DialogViewConfiguration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DialogViewConfiguration *_t = static_cast<DialogViewConfiguration *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->apply(); break;
        case 1: _t->slotDropped((*reinterpret_cast< DialogViewConfigurationWidget*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< DialogViewConfigurationItem*(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 2: _t->moveSelectionToActiveList(); break;
        case 3: _t->moveSelectionToInactiveList(); break;
        case 4: _t->selectionChangedActive(); break;
        case 5: _t->selectionChangedInactive(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DialogViewConfigurationWidget* >(); break;
            }
            break;
        }
    }
}

const QMetaObject DialogViewConfiguration::staticMetaObject = {
    { &DialogBase::staticMetaObject, qt_meta_stringdata_DialogViewConfiguration.data,
      qt_meta_data_DialogViewConfiguration,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DialogViewConfiguration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DialogViewConfiguration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DialogViewConfiguration.stringdata0))
        return static_cast<void*>(this);
    return DialogBase::qt_metacast(_clname);
}

int DialogViewConfiguration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DialogBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
