/****************************************************************************
** Meta object code from reading C++ file 'mixdevicewidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/gui/mixdevicewidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mixdevicewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MixDeviceWidget_t {
    QByteArrayData data[13];
    char stringdata0[137];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MixDeviceWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MixDeviceWidget_t qt_meta_stringdata_MixDeviceWidget = {
    {
QT_MOC_LITERAL(0, 0, 15), // "MixDeviceWidget"
QT_MOC_LITERAL(1, 16, 19), // "guiVisibilityChange"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 16), // "MixDeviceWidget*"
QT_MOC_LITERAL(4, 54, 6), // "source"
QT_MOC_LITERAL(5, 61, 6), // "enable"
QT_MOC_LITERAL(6, 68, 10), // "defineKeys"
QT_MOC_LITERAL(7, 79, 15), // "showContextMenu"
QT_MOC_LITERAL(8, 95, 3), // "pos"
QT_MOC_LITERAL(9, 99, 6), // "update"
QT_MOC_LITERAL(10, 106, 11), // "setDisabled"
QT_MOC_LITERAL(11, 118, 5), // "value"
QT_MOC_LITERAL(12, 124, 12) // "volumeChange"

    },
    "MixDeviceWidget\0guiVisibilityChange\0"
    "\0MixDeviceWidget*\0source\0enable\0"
    "defineKeys\0showContextMenu\0pos\0update\0"
    "setDisabled\0value\0volumeChange"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MixDeviceWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   54,    2, 0x0a /* Public */,
       7,    1,   55,    2, 0x0a /* Public */,
       7,    0,   58,    2, 0x2a /* Public | MethodCloned */,
       9,    0,   59,    2, 0x0a /* Public */,
      10,    1,   60,    2, 0x09 /* Protected */,
      12,    1,   63,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    4,    5,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void MixDeviceWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MixDeviceWidget *_t = static_cast<MixDeviceWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->guiVisibilityChange((*reinterpret_cast< MixDeviceWidget*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->defineKeys(); break;
        case 2: _t->showContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 3: _t->showContextMenu(); break;
        case 4: _t->update(); break;
        case 5: _t->setDisabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->volumeChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MixDeviceWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MixDeviceWidget::*_t)(MixDeviceWidget * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MixDeviceWidget::guiVisibilityChange)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject MixDeviceWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_MixDeviceWidget.data,
      qt_meta_data_MixDeviceWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *MixDeviceWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MixDeviceWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MixDeviceWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MixDeviceWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void MixDeviceWidget::guiVisibilityChange(MixDeviceWidget * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
