/****************************************************************************
** Meta object code from reading C++ file 'kmixdockwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/gui/kmixdockwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmixdockwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMixDockWidget_t {
    QByteArrayData data[13];
    char stringdata0[150];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMixDockWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMixDockWidget_t qt_meta_stringdata_KMixDockWidget = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KMixDockWidget"
QT_MOC_LITERAL(1, 15, 12), // "setVolumeTip"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 12), // "updatePixmap"
QT_MOC_LITERAL(4, 42, 8), // "activate"
QT_MOC_LITERAL(5, 51, 3), // "pos"
QT_MOC_LITERAL(6, 55, 14), // "controlsChange"
QT_MOC_LITERAL(7, 70, 10), // "changeType"
QT_MOC_LITERAL(8, 81, 8), // "dockMute"
QT_MOC_LITERAL(9, 90, 14), // "trayWheelEvent"
QT_MOC_LITERAL(10, 105, 5), // "delta"
QT_MOC_LITERAL(11, 111, 15), // "Qt::Orientation"
QT_MOC_LITERAL(12, 127, 22) // "contextMenuAboutToShow"

    },
    "KMixDockWidget\0setVolumeTip\0\0updatePixmap\0"
    "activate\0pos\0controlsChange\0changeType\0"
    "dockMute\0trayWheelEvent\0delta\0"
    "Qt::Orientation\0contextMenuAboutToShow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMixDockWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x0a /* Public */,
       3,    0,   50,    2, 0x0a /* Public */,
       4,    1,   51,    2, 0x0a /* Public */,
       6,    1,   54,    2, 0x0a /* Public */,
       8,    0,   57,    2, 0x08 /* Private */,
       9,    2,   58,    2, 0x08 /* Private */,
      12,    0,   63,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 11,   10,    2,
    QMetaType::Void,

       0        // eod
};

void KMixDockWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMixDockWidget *_t = static_cast<KMixDockWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setVolumeTip(); break;
        case 1: _t->updatePixmap(); break;
        case 2: _t->activate((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 3: _t->controlsChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->dockMute(); break;
        case 5: _t->trayWheelEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::Orientation(*)>(_a[2]))); break;
        case 6: _t->contextMenuAboutToShow(); break;
        default: ;
        }
    }
}

const QMetaObject KMixDockWidget::staticMetaObject = {
    { &KStatusNotifierItem::staticMetaObject, qt_meta_stringdata_KMixDockWidget.data,
      qt_meta_data_KMixDockWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMixDockWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMixDockWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMixDockWidget.stringdata0))
        return static_cast<void*>(this);
    return KStatusNotifierItem::qt_metacast(_clname);
}

int KMixDockWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KStatusNotifierItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
