/****************************************************************************
** Meta object code from reading C++ file 'dbuscontrolwrapper.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/dbus/dbuscontrolwrapper.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbuscontrolwrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DBusControlWrapper_t {
    QByteArrayData data[12];
    char stringdata0[145];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DBusControlWrapper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DBusControlWrapper_t qt_meta_stringdata_DBusControlWrapper = {
    {
QT_MOC_LITERAL(0, 0, 18), // "DBusControlWrapper"
QT_MOC_LITERAL(1, 19, 2), // "id"
QT_MOC_LITERAL(2, 22, 12), // "readableName"
QT_MOC_LITERAL(3, 35, 8), // "iconName"
QT_MOC_LITERAL(4, 44, 6), // "volume"
QT_MOC_LITERAL(5, 51, 14), // "absoluteVolume"
QT_MOC_LITERAL(6, 66, 17), // "absoluteVolumeMin"
QT_MOC_LITERAL(7, 84, 17), // "absoluteVolumeMax"
QT_MOC_LITERAL(8, 102, 4), // "mute"
QT_MOC_LITERAL(9, 107, 12), // "recordSource"
QT_MOC_LITERAL(10, 120, 7), // "canMute"
QT_MOC_LITERAL(11, 128, 16) // "hasCaptureSwitch"

    },
    "DBusControlWrapper\0id\0readableName\0"
    "iconName\0volume\0absoluteVolume\0"
    "absoluteVolumeMin\0absoluteVolumeMax\0"
    "mute\0recordSource\0canMute\0hasCaptureSwitch"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DBusControlWrapper[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
      11,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QString, 0x00095001,
       2, QMetaType::QString, 0x00095001,
       3, QMetaType::QString, 0x00095001,
       4, QMetaType::Int, 0x00095103,
       5, QMetaType::Long, 0x00095103,
       6, QMetaType::Long, 0x00095001,
       7, QMetaType::Long, 0x00095001,
       8, QMetaType::Bool, 0x00095103,
       9, QMetaType::Bool, 0x00095103,
      10, QMetaType::Bool, 0x00095001,
      11, QMetaType::Bool, 0x00095001,

       0        // eod
};

void DBusControlWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        DBusControlWrapper *_t = static_cast<DBusControlWrapper *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->readableName(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->iconName(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->volume(); break;
        case 4: *reinterpret_cast< long*>(_v) = _t->absoluteVolume(); break;
        case 5: *reinterpret_cast< long*>(_v) = _t->absoluteVolumeMin(); break;
        case 6: *reinterpret_cast< long*>(_v) = _t->absoluteVolumeMax(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->isMuted(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->isRecordSource(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->canMute(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->hasCaptureSwitch(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        DBusControlWrapper *_t = static_cast<DBusControlWrapper *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setVolume(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setAbsoluteVolume(*reinterpret_cast< long*>(_v)); break;
        case 7: _t->setMute(*reinterpret_cast< bool*>(_v)); break;
        case 8: _t->setRecordSource(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject DBusControlWrapper::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_DBusControlWrapper.data,
      qt_meta_data_DBusControlWrapper,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DBusControlWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusControlWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DBusControlWrapper.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusControlWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    
#ifndef QT_NO_PROPERTIES
   if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 11;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
