/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p control_interface /usr/src/ports/kmix/kmix-17.12.3-1.x86_64/src/kmix-17.12.3/dbus/org.kde.kmix.control.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef CONTROL_INTERFACE_H
#define CONTROL_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.KMix.Control
 */
class OrgKdeKMixControlInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.KMix.Control"; }

public:
    OrgKdeKMixControlInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKMixControlInterface();

    Q_PROPERTY(int absoluteVolume READ absoluteVolume WRITE setAbsoluteVolume)
    inline int absoluteVolume() const
    { return qvariant_cast< int >(property("absoluteVolume")); }
    inline void setAbsoluteVolume(int value)
    { setProperty("absoluteVolume", QVariant::fromValue(value)); }

    Q_PROPERTY(int absoluteVolumeMax READ absoluteVolumeMax)
    inline int absoluteVolumeMax() const
    { return qvariant_cast< int >(property("absoluteVolumeMax")); }

    Q_PROPERTY(int absoluteVolumeMin READ absoluteVolumeMin)
    inline int absoluteVolumeMin() const
    { return qvariant_cast< int >(property("absoluteVolumeMin")); }

    Q_PROPERTY(bool canMute READ canMute)
    inline bool canMute() const
    { return qvariant_cast< bool >(property("canMute")); }

    Q_PROPERTY(bool hasCaptureSwitch READ hasCaptureSwitch)
    inline bool hasCaptureSwitch() const
    { return qvariant_cast< bool >(property("hasCaptureSwitch")); }

    Q_PROPERTY(QString iconName READ iconName)
    inline QString iconName() const
    { return qvariant_cast< QString >(property("iconName")); }

    Q_PROPERTY(QString id READ id)
    inline QString id() const
    { return qvariant_cast< QString >(property("id")); }

    Q_PROPERTY(bool mute READ mute WRITE setMute)
    inline bool mute() const
    { return qvariant_cast< bool >(property("mute")); }
    inline void setMute(bool value)
    { setProperty("mute", QVariant::fromValue(value)); }

    Q_PROPERTY(QString readableName READ readableName)
    inline QString readableName() const
    { return qvariant_cast< QString >(property("readableName")); }

    Q_PROPERTY(bool recordSource READ recordSource WRITE setRecordSource)
    inline bool recordSource() const
    { return qvariant_cast< bool >(property("recordSource")); }
    inline void setRecordSource(bool value)
    { setProperty("recordSource", QVariant::fromValue(value)); }

    Q_PROPERTY(int volume READ volume WRITE setVolume)
    inline int volume() const
    { return qvariant_cast< int >(property("volume")); }
    inline void setVolume(int value)
    { setProperty("volume", QVariant::fromValue(value)); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> decreaseVolume()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("decreaseVolume"), argumentList);
    }

    inline QDBusPendingReply<> increaseVolume()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("increaseVolume"), argumentList);
    }

    inline QDBusPendingReply<> toggleMute()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("toggleMute"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace KMix {
      typedef ::OrgKdeKMixControlInterface Control;
    }
  }
}
#endif
