/****************************************************************************
** Meta object code from reading C++ file 'kmix.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/apps/kmix.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmix.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMixWindow_t {
    QByteArrayData data[48];
    char stringdata0[582];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMixWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMixWindow_t qt_meta_stringdata_KMixWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "KMixWindow"
QT_MOC_LITERAL(1, 11, 14), // "controlsChange"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 10), // "changeType"
QT_MOC_LITERAL(4, 38, 4), // "quit"
QT_MOC_LITERAL(5, 43, 12), // "showSettings"
QT_MOC_LITERAL(6, 56, 8), // "showHelp"
QT_MOC_LITERAL(7, 65, 9), // "showAbout"
QT_MOC_LITERAL(8, 75, 13), // "toggleMenuBar"
QT_MOC_LITERAL(9, 89, 11), // "loadVolumes"
QT_MOC_LITERAL(10, 101, 7), // "postfix"
QT_MOC_LITERAL(11, 109, 11), // "saveVolumes"
QT_MOC_LITERAL(12, 121, 10), // "saveConfig"
QT_MOC_LITERAL(13, 132, 10), // "applyPrefs"
QT_MOC_LITERAL(14, 143, 11), // "recreateGUI"
QT_MOC_LITERAL(15, 155, 8), // "saveView"
QT_MOC_LITERAL(16, 164, 5), // "reset"
QT_MOC_LITERAL(17, 170, 7), // "mixerId"
QT_MOC_LITERAL(18, 178, 11), // "forceNewTab"
QT_MOC_LITERAL(19, 190, 25), // "recreateGUIwithSavingView"
QT_MOC_LITERAL(20, 216, 13), // "newMixerShown"
QT_MOC_LITERAL(21, 230, 8), // "tabIndex"
QT_MOC_LITERAL(22, 239, 16), // "slotSelectMaster"
QT_MOC_LITERAL(23, 256, 10), // "slotHWInfo"
QT_MOC_LITERAL(24, 267, 21), // "slotKdeAudioSetupExec"
QT_MOC_LITERAL(25, 289, 24), // "slotConfigureCurrentView"
QT_MOC_LITERAL(26, 314, 7), // "plugged"
QT_MOC_LITERAL(27, 322, 11), // "const char*"
QT_MOC_LITERAL(28, 334, 10), // "driverName"
QT_MOC_LITERAL(29, 345, 3), // "udi"
QT_MOC_LITERAL(30, 349, 8), // "QString&"
QT_MOC_LITERAL(31, 358, 3), // "dev"
QT_MOC_LITERAL(32, 362, 9), // "unplugged"
QT_MOC_LITERAL(33, 372, 11), // "hideOrClose"
QT_MOC_LITERAL(34, 384, 18), // "slotIncreaseVolume"
QT_MOC_LITERAL(35, 403, 18), // "slotDecreaseVolume"
QT_MOC_LITERAL(36, 422, 8), // "slotMute"
QT_MOC_LITERAL(37, 431, 21), // "slotSelectMasterClose"
QT_MOC_LITERAL(38, 453, 7), // "newView"
QT_MOC_LITERAL(39, 461, 16), // "saveAndCloseView"
QT_MOC_LITERAL(40, 478, 12), // "loadVolumes1"
QT_MOC_LITERAL(41, 491, 12), // "loadVolumes2"
QT_MOC_LITERAL(42, 504, 12), // "loadVolumes3"
QT_MOC_LITERAL(43, 517, 12), // "loadVolumes4"
QT_MOC_LITERAL(44, 530, 12), // "saveVolumes1"
QT_MOC_LITERAL(45, 543, 12), // "saveVolumes2"
QT_MOC_LITERAL(46, 556, 12), // "saveVolumes3"
QT_MOC_LITERAL(47, 569, 12) // "saveVolumes4"

    },
    "KMixWindow\0controlsChange\0\0changeType\0"
    "quit\0showSettings\0showHelp\0showAbout\0"
    "toggleMenuBar\0loadVolumes\0postfix\0"
    "saveVolumes\0saveConfig\0applyPrefs\0"
    "recreateGUI\0saveView\0reset\0mixerId\0"
    "forceNewTab\0recreateGUIwithSavingView\0"
    "newMixerShown\0tabIndex\0slotSelectMaster\0"
    "slotHWInfo\0slotKdeAudioSetupExec\0"
    "slotConfigureCurrentView\0plugged\0"
    "const char*\0driverName\0udi\0QString&\0"
    "dev\0unplugged\0hideOrClose\0slotIncreaseVolume\0"
    "slotDecreaseVolume\0slotMute\0"
    "slotSelectMasterClose\0newView\0"
    "saveAndCloseView\0loadVolumes1\0"
    "loadVolumes2\0loadVolumes3\0loadVolumes4\0"
    "saveVolumes1\0saveVolumes2\0saveVolumes3\0"
    "saveVolumes4"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMixWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      37,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  199,    2, 0x0a /* Public */,
       4,    0,  202,    2, 0x0a /* Public */,
       5,    0,  203,    2, 0x0a /* Public */,
       6,    0,  204,    2, 0x0a /* Public */,
       7,    0,  205,    2, 0x0a /* Public */,
       8,    0,  206,    2, 0x0a /* Public */,
       9,    0,  207,    2, 0x0a /* Public */,
       9,    1,  208,    2, 0x0a /* Public */,
      11,    0,  211,    2, 0x0a /* Public */,
      11,    1,  212,    2, 0x0a /* Public */,
      12,    0,  215,    2, 0x0a /* Public */,
      13,    0,  216,    2, 0x0a /* Public */,
      14,    2,  217,    2, 0x0a /* Public */,
      14,    4,  222,    2, 0x0a /* Public */,
      19,    0,  231,    2, 0x0a /* Public */,
      20,    1,  232,    2, 0x0a /* Public */,
      22,    0,  235,    2, 0x0a /* Public */,
      23,    0,  236,    2, 0x08 /* Private */,
      24,    0,  237,    2, 0x08 /* Private */,
      25,    0,  238,    2, 0x08 /* Private */,
      26,    3,  239,    2, 0x08 /* Private */,
      32,    1,  246,    2, 0x08 /* Private */,
      33,    0,  249,    2, 0x08 /* Private */,
      34,    0,  250,    2, 0x08 /* Private */,
      35,    0,  251,    2, 0x08 /* Private */,
      36,    0,  252,    2, 0x08 /* Private */,
      37,    1,  253,    2, 0x08 /* Private */,
      38,    0,  256,    2, 0x08 /* Private */,
      39,    1,  257,    2, 0x08 /* Private */,
      40,    0,  260,    2, 0x08 /* Private */,
      41,    0,  261,    2, 0x08 /* Private */,
      42,    0,  262,    2, 0x08 /* Private */,
      43,    0,  263,    2, 0x08 /* Private */,
      44,    0,  264,    2, 0x08 /* Private */,
      45,    0,  265,    2, 0x08 /* Private */,
      46,    0,  266,    2, 0x08 /* Private */,
      47,    0,  267,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,   15,   16,
    QMetaType::Void, QMetaType::Bool, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   12,   17,   18,   16,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 27, QMetaType::QString, 0x80000000 | 30,   28,   29,   31,
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QObjectStar,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KMixWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMixWindow *_t = static_cast<KMixWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->controlsChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->quit(); break;
        case 2: _t->showSettings(); break;
        case 3: _t->showHelp(); break;
        case 4: _t->showAbout(); break;
        case 5: _t->toggleMenuBar(); break;
        case 6: _t->loadVolumes(); break;
        case 7: _t->loadVolumes((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 8: _t->saveVolumes(); break;
        case 9: _t->saveVolumes((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 10: _t->saveConfig(); break;
        case 11: _t->applyPrefs(); break;
        case 12: _t->recreateGUI((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 13: _t->recreateGUI((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 14: _t->recreateGUIwithSavingView(); break;
        case 15: _t->newMixerShown((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->slotSelectMaster(); break;
        case 17: _t->slotHWInfo(); break;
        case 18: _t->slotKdeAudioSetupExec(); break;
        case 19: _t->slotConfigureCurrentView(); break;
        case 20: _t->plugged((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 21: _t->unplugged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->hideOrClose(); break;
        case 23: _t->slotIncreaseVolume(); break;
        case 24: _t->slotDecreaseVolume(); break;
        case 25: _t->slotMute(); break;
        case 26: _t->slotSelectMasterClose((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 27: _t->newView(); break;
        case 28: _t->saveAndCloseView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->loadVolumes1(); break;
        case 30: _t->loadVolumes2(); break;
        case 31: _t->loadVolumes3(); break;
        case 32: _t->loadVolumes4(); break;
        case 33: _t->saveVolumes1(); break;
        case 34: _t->saveVolumes2(); break;
        case 35: _t->saveVolumes3(); break;
        case 36: _t->saveVolumes4(); break;
        default: ;
        }
    }
}

const QMetaObject KMixWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KMixWindow.data,
      qt_meta_data_KMixWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMixWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMixWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMixWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KMixWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 37;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
