/****************************************************************************
** Meta object code from reading C++ file 'kmixdevicemanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/core/kmixdevicemanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmixdevicemanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMixDeviceManager_t {
    QByteArrayData data[11];
    char stringdata0[103];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMixDeviceManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMixDeviceManager_t qt_meta_stringdata_KMixDeviceManager = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KMixDeviceManager"
QT_MOC_LITERAL(1, 18, 7), // "plugged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 11), // "const char*"
QT_MOC_LITERAL(4, 39, 10), // "driverName"
QT_MOC_LITERAL(5, 50, 3), // "udi"
QT_MOC_LITERAL(6, 54, 8), // "QString&"
QT_MOC_LITERAL(7, 63, 3), // "dev"
QT_MOC_LITERAL(8, 67, 9), // "unplugged"
QT_MOC_LITERAL(9, 77, 11), // "pluggedSlot"
QT_MOC_LITERAL(10, 89, 13) // "unpluggedSlot"

    },
    "KMixDeviceManager\0plugged\0\0const char*\0"
    "driverName\0udi\0QString&\0dev\0unplugged\0"
    "pluggedSlot\0unpluggedSlot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMixDeviceManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   34,    2, 0x06 /* Public */,
       8,    1,   41,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   44,    2, 0x08 /* Private */,
      10,    1,   47,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, 0x80000000 | 6,    4,    5,    7,
    QMetaType::Void, QMetaType::QString,    5,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void KMixDeviceManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMixDeviceManager *_t = static_cast<KMixDeviceManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->plugged((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 1: _t->unplugged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->pluggedSlot((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->unpluggedSlot((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KMixDeviceManager::*_t)(const char * , const QString & , QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KMixDeviceManager::plugged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KMixDeviceManager::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KMixDeviceManager::unplugged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KMixDeviceManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KMixDeviceManager.data,
      qt_meta_data_KMixDeviceManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMixDeviceManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMixDeviceManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMixDeviceManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KMixDeviceManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KMixDeviceManager::plugged(const char * _t1, const QString & _t2, QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KMixDeviceManager::unplugged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
