/****************************************************************************
** Meta object code from reading C++ file 'mixer_mpris2.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/backends/mixer_mpris2.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mixer_mpris2.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MPrisControl_t {
    QByteArrayData data[10];
    char stringdata0[136];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MPrisControl_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MPrisControl_t qt_meta_stringdata_MPrisControl = {
    {
QT_MOC_LITERAL(0, 0, 12), // "MPrisControl"
QT_MOC_LITERAL(1, 13, 13), // "volumeChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 13), // "MPrisControl*"
QT_MOC_LITERAL(4, 42, 3), // "mad"
QT_MOC_LITERAL(5, 46, 20), // "playbackStateChanged"
QT_MOC_LITERAL(6, 67, 26), // "MediaController::PlayState"
QT_MOC_LITERAL(7, 94, 20), // "trackChangedIncoming"
QT_MOC_LITERAL(8, 115, 3), // "msg"
QT_MOC_LITERAL(9, 119, 16) // "onPropertyChange"

    },
    "MPrisControl\0volumeChanged\0\0MPrisControl*\0"
    "mad\0playbackStateChanged\0"
    "MediaController::PlayState\0"
    "trackChangedIncoming\0msg\0onPropertyChange"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MPrisControl[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   34,    2, 0x06 /* Public */,
       5,    2,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   44,    2, 0x0a /* Public */,
       9,    3,   47,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Double,    4,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 6,    4,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QVariantMap,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap, QMetaType::QStringList,    2,    2,    2,

       0        // eod
};

void MPrisControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MPrisControl *_t = static_cast<MPrisControl *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->volumeChanged((*reinterpret_cast< MPrisControl*(*)>(_a[1])),(*reinterpret_cast< double(*)>(_a[2]))); break;
        case 1: _t->playbackStateChanged((*reinterpret_cast< MPrisControl*(*)>(_a[1])),(*reinterpret_cast< MediaController::PlayState(*)>(_a[2]))); break;
        case 2: _t->trackChangedIncoming((*reinterpret_cast< QVariantMap(*)>(_a[1]))); break;
        case 3: _t->onPropertyChange((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QVariantMap(*)>(_a[2])),(*reinterpret_cast< QStringList(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MPrisControl* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MPrisControl* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MPrisControl::*_t)(MPrisControl * , double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MPrisControl::volumeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MPrisControl::*_t)(MPrisControl * , MediaController::PlayState );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MPrisControl::playbackStateChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject MPrisControl::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_MPrisControl.data,
      qt_meta_data_MPrisControl,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *MPrisControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MPrisControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MPrisControl.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MPrisControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void MPrisControl::volumeChanged(MPrisControl * _t1, double _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MPrisControl::playbackStateChanged(MPrisControl * _t1, MediaController::PlayState _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_Mixer_MPRIS2_t {
    QByteArrayData data[24];
    char stringdata0[358];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Mixer_MPRIS2_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Mixer_MPRIS2_t qt_meta_stringdata_Mixer_MPRIS2 = {
    {
QT_MOC_LITERAL(0, 0, 12), // "Mixer_MPRIS2"
QT_MOC_LITERAL(1, 13, 13), // "volumeChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 13), // "MPrisControl*"
QT_MOC_LITERAL(4, 42, 3), // "mad"
QT_MOC_LITERAL(5, 46, 20), // "playbackStateChanged"
QT_MOC_LITERAL(6, 67, 26), // "MediaController::PlayState"
QT_MOC_LITERAL(7, 94, 14), // "newMediaPlayer"
QT_MOC_LITERAL(8, 109, 4), // "name"
QT_MOC_LITERAL(9, 114, 8), // "oldOwner"
QT_MOC_LITERAL(10, 123, 8), // "newOwner"
QT_MOC_LITERAL(11, 132, 20), // "addMprisControlAsync"
QT_MOC_LITERAL(12, 153, 4), // "arg1"
QT_MOC_LITERAL(13, 158, 24), // "announceControlListAsync"
QT_MOC_LITERAL(14, 183, 8), // "streamId"
QT_MOC_LITERAL(15, 192, 19), // "announceControlList"
QT_MOC_LITERAL(16, 212, 11), // "announceGUI"
QT_MOC_LITERAL(17, 224, 14), // "announceVolume"
QT_MOC_LITERAL(18, 239, 19), // "watcherMediaControl"
QT_MOC_LITERAL(19, 259, 24), // "QDBusPendingCallWatcher*"
QT_MOC_LITERAL(20, 284, 7), // "watcher"
QT_MOC_LITERAL(21, 292, 20), // "watcherPlugControlId"
QT_MOC_LITERAL(22, 313, 20), // "watcherInitialVolume"
QT_MOC_LITERAL(23, 334, 23) // "watcherInitialPlayState"

    },
    "Mixer_MPRIS2\0volumeChanged\0\0MPrisControl*\0"
    "mad\0playbackStateChanged\0"
    "MediaController::PlayState\0newMediaPlayer\0"
    "name\0oldOwner\0newOwner\0addMprisControlAsync\0"
    "arg1\0announceControlListAsync\0streamId\0"
    "announceControlList\0announceGUI\0"
    "announceVolume\0watcherMediaControl\0"
    "QDBusPendingCallWatcher*\0watcher\0"
    "watcherPlugControlId\0watcherInitialVolume\0"
    "watcherInitialPlayState"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Mixer_MPRIS2[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   74,    2, 0x0a /* Public */,
       5,    2,   79,    2, 0x0a /* Public */,
       7,    3,   84,    2, 0x0a /* Public */,
      11,    1,   91,    2, 0x0a /* Public */,
      13,    1,   94,    2, 0x0a /* Public */,
      15,    0,   97,    2, 0x08 /* Private */,
      16,    0,   98,    2, 0x08 /* Private */,
      17,    0,   99,    2, 0x08 /* Private */,
      18,    1,  100,    2, 0x08 /* Private */,
      21,    1,  103,    2, 0x08 /* Private */,
      22,    1,  106,    2, 0x08 /* Private */,
      23,    1,  109,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Double,    4,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 6,    4,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    8,    9,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void, 0x80000000 | 19,   20,

       0        // eod
};

void Mixer_MPRIS2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Mixer_MPRIS2 *_t = static_cast<Mixer_MPRIS2 *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->volumeChanged((*reinterpret_cast< MPrisControl*(*)>(_a[1])),(*reinterpret_cast< double(*)>(_a[2]))); break;
        case 1: _t->playbackStateChanged((*reinterpret_cast< MPrisControl*(*)>(_a[1])),(*reinterpret_cast< MediaController::PlayState(*)>(_a[2]))); break;
        case 2: _t->newMediaPlayer((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 3: _t->addMprisControlAsync((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: _t->announceControlListAsync((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->announceControlList(); break;
        case 6: _t->announceGUI(); break;
        case 7: _t->announceVolume(); break;
        case 8: _t->watcherMediaControl((*reinterpret_cast< QDBusPendingCallWatcher*(*)>(_a[1]))); break;
        case 9: _t->watcherPlugControlId((*reinterpret_cast< QDBusPendingCallWatcher*(*)>(_a[1]))); break;
        case 10: _t->watcherInitialVolume((*reinterpret_cast< QDBusPendingCallWatcher*(*)>(_a[1]))); break;
        case 11: _t->watcherInitialPlayState((*reinterpret_cast< QDBusPendingCallWatcher*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MPrisControl* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MPrisControl* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
}

const QMetaObject Mixer_MPRIS2::staticMetaObject = {
    { &Mixer_Backend::staticMetaObject, qt_meta_stringdata_Mixer_MPRIS2.data,
      qt_meta_data_Mixer_MPRIS2,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Mixer_MPRIS2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Mixer_MPRIS2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Mixer_MPRIS2.stringdata0))
        return static_cast<void*>(this);
    return Mixer_Backend::qt_metacast(_clname);
}

int Mixer_MPRIS2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Mixer_Backend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
