/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p mixer_interface /usr/src/ports/kmix/kmix-17.12.3-1.x86_64/src/kmix-17.12.3/dbus/org.kde.kmix.mixer.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef MIXER_INTERFACE_H
#define MIXER_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.KMix.Mixer
 */
class OrgKdeKMixMixerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.KMix.Mixer"; }

public:
    OrgKdeKMixMixerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKMixMixerInterface();

    Q_PROPERTY(int balance READ balance WRITE setBalance)
    inline int balance() const
    { return qvariant_cast< int >(property("balance")); }
    inline void setBalance(int value)
    { setProperty("balance", QVariant::fromValue(value)); }

    Q_PROPERTY(QStringList controls READ controls)
    inline QStringList controls() const
    { return qvariant_cast< QStringList >(property("controls")); }

    Q_PROPERTY(QString driverName READ driverName)
    inline QString driverName() const
    { return qvariant_cast< QString >(property("driverName")); }

    Q_PROPERTY(QString id READ id)
    inline QString id() const
    { return qvariant_cast< QString >(property("id")); }

    Q_PROPERTY(QString masterControl READ masterControl)
    inline QString masterControl() const
    { return qvariant_cast< QString >(property("masterControl")); }

    Q_PROPERTY(bool opened READ opened)
    inline bool opened() const
    { return qvariant_cast< bool >(property("opened")); }

    Q_PROPERTY(QString readableName READ readableName)
    inline QString readableName() const
    { return qvariant_cast< QString >(property("readableName")); }

    Q_PROPERTY(QString udi READ udi)
    inline QString udi() const
    { return qvariant_cast< QString >(property("udi")); }

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void changed();
    void controlChanged();
};

namespace org {
  namespace kde {
    namespace KMix {
      typedef ::OrgKdeKMixMixerInterface Mixer;
    }
  }
}
#endif
