/****************************************************************************
** Meta object code from reading C++ file 'mdwslider.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmix-17.12.3/gui/mdwslider.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mdwslider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MDWSlider_t {
    QByteArrayData data[33];
    char stringdata0[399];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MDWSlider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MDWSlider_t qt_meta_stringdata_MDWSlider = {
    {
QT_MOC_LITERAL(0, 0, 9), // "MDWSlider"
QT_MOC_LITERAL(1, 10, 12), // "toggleRecsrc"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 11), // "toggleMuted"
QT_MOC_LITERAL(4, 36, 18), // "toggleStereoLinked"
QT_MOC_LITERAL(5, 55, 11), // "setDisabled"
QT_MOC_LITERAL(6, 67, 5), // "value"
QT_MOC_LITERAL(7, 73, 6), // "update"
QT_MOC_LITERAL(8, 80, 12), // "showMoveMenu"
QT_MOC_LITERAL(9, 93, 15), // "showContextMenu"
QT_MOC_LITERAL(10, 109, 3), // "pos"
QT_MOC_LITERAL(11, 113, 24), // "increaseOrDecreaseVolume"
QT_MOC_LITERAL(12, 138, 4), // "arg1"
QT_MOC_LITERAL(13, 143, 22), // "Volume::VolumeTypeFlag"
QT_MOC_LITERAL(14, 166, 10), // "volumeType"
QT_MOC_LITERAL(15, 177, 9), // "extraData"
QT_MOC_LITERAL(16, 187, 16), // "QAbstractSlider*"
QT_MOC_LITERAL(17, 204, 6), // "slider"
QT_MOC_LITERAL(18, 211, 16), // "addMediaControls"
QT_MOC_LITERAL(19, 228, 11), // "QBoxLayout*"
QT_MOC_LITERAL(20, 240, 9), // "setRecsrc"
QT_MOC_LITERAL(21, 250, 8), // "setMuted"
QT_MOC_LITERAL(22, 259, 12), // "volumeChange"
QT_MOC_LITERAL(23, 272, 13), // "sliderPressed"
QT_MOC_LITERAL(24, 286, 14), // "sliderReleased"
QT_MOC_LITERAL(25, 301, 14), // "increaseVolume"
QT_MOC_LITERAL(26, 316, 14), // "decreaseVolume"
QT_MOC_LITERAL(27, 331, 19), // "moveStreamAutomatic"
QT_MOC_LITERAL(28, 351, 10), // "moveStream"
QT_MOC_LITERAL(29, 362, 6), // "destId"
QT_MOC_LITERAL(30, 369, 9), // "mediaPlay"
QT_MOC_LITERAL(31, 379, 9), // "mediaNext"
QT_MOC_LITERAL(32, 389, 9) // "mediaPrev"

    },
    "MDWSlider\0toggleRecsrc\0\0toggleMuted\0"
    "toggleStereoLinked\0setDisabled\0value\0"
    "update\0showMoveMenu\0showContextMenu\0"
    "pos\0increaseOrDecreaseVolume\0arg1\0"
    "Volume::VolumeTypeFlag\0volumeType\0"
    "extraData\0QAbstractSlider*\0slider\0"
    "addMediaControls\0QBoxLayout*\0setRecsrc\0"
    "setMuted\0volumeChange\0sliderPressed\0"
    "sliderReleased\0increaseVolume\0"
    "decreaseVolume\0moveStreamAutomatic\0"
    "moveStream\0destId\0mediaPlay\0mediaNext\0"
    "mediaPrev"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MDWSlider[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      23,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  129,    2, 0x0a /* Public */,
       3,    0,  130,    2, 0x0a /* Public */,
       4,    0,  131,    2, 0x0a /* Public */,
       5,    1,  132,    2, 0x0a /* Public */,
       7,    0,  135,    2, 0x0a /* Public */,
       8,    0,  136,    2, 0x0a /* Public */,
       9,    1,  137,    2, 0x0a /* Public */,
       9,    0,  140,    2, 0x2a /* Public | MethodCloned */,
      11,    2,  141,    2, 0x0a /* Public */,
      15,    1,  146,    2, 0x0a /* Public */,
      18,    1,  149,    2, 0x0a /* Public */,
      20,    1,  152,    2, 0x08 /* Private */,
      21,    1,  155,    2, 0x08 /* Private */,
      22,    1,  158,    2, 0x08 /* Private */,
      23,    0,  161,    2, 0x08 /* Private */,
      24,    0,  162,    2, 0x08 /* Private */,
      25,    0,  163,    2, 0x08 /* Private */,
      26,    0,  164,    2, 0x08 /* Private */,
      27,    0,  165,    2, 0x08 /* Private */,
      28,    1,  166,    2, 0x08 /* Private */,
      30,    1,  169,    2, 0x08 /* Private */,
      31,    1,  172,    2, 0x08 /* Private */,
      32,    1,  175,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, 0x80000000 | 13,   12,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 19,   12,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void MDWSlider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MDWSlider *_t = static_cast<MDWSlider *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->toggleRecsrc(); break;
        case 1: _t->toggleMuted(); break;
        case 2: _t->toggleStereoLinked(); break;
        case 3: _t->setDisabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->update(); break;
        case 5: _t->showMoveMenu(); break;
        case 6: _t->showContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 7: _t->showContextMenu(); break;
        case 8: _t->increaseOrDecreaseVolume((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< Volume::VolumeTypeFlag(*)>(_a[2]))); break;
        case 9: _t->extraData((*reinterpret_cast< QAbstractSlider*(*)>(_a[1]))); break;
        case 10: _t->addMediaControls((*reinterpret_cast< QBoxLayout*(*)>(_a[1]))); break;
        case 11: _t->setRecsrc((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->setMuted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->volumeChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->sliderPressed(); break;
        case 15: _t->sliderReleased(); break;
        case 16: _t->increaseVolume(); break;
        case 17: _t->decreaseVolume(); break;
        case 18: _t->moveStreamAutomatic(); break;
        case 19: _t->moveStream((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 20: _t->mediaPlay((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->mediaNext((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->mediaPrev((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSlider* >(); break;
            }
            break;
        }
    }
}

const QMetaObject MDWSlider::staticMetaObject = {
    { &MixDeviceWidget::staticMetaObject, qt_meta_stringdata_MDWSlider.data,
      qt_meta_data_MDWSlider,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *MDWSlider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MDWSlider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MDWSlider.stringdata0))
        return static_cast<void*>(this);
    return MixDeviceWidget::qt_metacast(_clname);
}

int MDWSlider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MixDeviceWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
