/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p mixset_interface /usr/src/ports/kmix/kmix-17.12.3-1.x86_64/src/kmix-17.12.3/dbus/org.kde.kmix.mixset.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef MIXSET_INTERFACE_H
#define MIXSET_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.KMix.MixSet
 */
class OrgKdeKMixMixSetInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.KMix.MixSet"; }

public:
    OrgKdeKMixMixSetInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKMixMixSetInterface();

    Q_PROPERTY(QString currentMasterControl READ currentMasterControl)
    inline QString currentMasterControl() const
    { return qvariant_cast< QString >(property("currentMasterControl")); }

    Q_PROPERTY(QString currentMasterMixer READ currentMasterMixer)
    inline QString currentMasterMixer() const
    { return qvariant_cast< QString >(property("currentMasterMixer")); }

    Q_PROPERTY(QStringList mixers READ mixers)
    inline QStringList mixers() const
    { return qvariant_cast< QStringList >(property("mixers")); }

    Q_PROPERTY(QString preferredMasterControl READ preferredMasterControl)
    inline QString preferredMasterControl() const
    { return qvariant_cast< QString >(property("preferredMasterControl")); }

    Q_PROPERTY(QString preferredMasterMixer READ preferredMasterMixer)
    inline QString preferredMasterMixer() const
    { return qvariant_cast< QString >(property("preferredMasterMixer")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> setCurrentMaster(const QString &mixer, const QString &control)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(mixer) << QVariant::fromValue(control);
        return asyncCallWithArgumentList(QStringLiteral("setCurrentMaster"), argumentList);
    }

    inline QDBusPendingReply<> setPreferredMaster(const QString &mixer, const QString &control)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(mixer) << QVariant::fromValue(control);
        return asyncCallWithArgumentList(QStringLiteral("setPreferredMaster"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void masterChanged();
    void mixersChanged();
};

namespace org {
  namespace kde {
    namespace KMix {
      typedef ::OrgKdeKMixMixSetInterface MixSet;
    }
  }
}
#endif
